@@ -37,7 +37,6 @@
 
 #include "gdk-pixbuf-private.h"
 #include "gdk-pixbuf-loader.h"
-#include "gdk-pixbuf-alias.h"
 
 #include <glib/gstdio.h>
 
@@ -822,7 +821,7 @@ _gdk_pixbuf_get_module (guchar *buffer, guint size,
                 mimes = info->mime_types;
                 for (j = 0; mimes[j] != NULL; j++) {
                         type = g_content_type_from_mime_type (mimes[j]);
-                        if (g_ascii_strcasecmp (type, mime_type) == 0) {
+                        if (g_content_type_equals (type, mime_type)) {
                                 g_free (type);
                                 selected = module;
                                 break;
@@ -2111,7 +2110,7 @@ gdk_pixbuf_savev (GdkPixbuf  *pixbuf,
 /**
  * gdk_pixbuf_save_to_callback:
  * @pixbuf: a #GdkPixbuf.
- * @save_func: a function that is called to save each block of data that
+ * @save_func: (scope call): a function that is called to save each block of data that
  *   the save routine generates.
  * @user_data: user data to pass to the save function.
  * @type: name of file format.
@@ -2165,7 +2164,7 @@ gdk_pixbuf_save_to_callback    (GdkPixbuf  *pixbuf,
 /**
  * gdk_pixbuf_save_to_callbackv:
  * @pixbuf: a #GdkPixbuf.
- * @save_func: a function that is called to save each block of data that
+ * @save_func: (scope call): a function that is called to save each block of data that
  *   the save routine generates.
  * @user_data: user data to pass to the save function.
  * @type: name of file format.
@@ -2503,7 +2502,7 @@ gdk_pixbuf_format_get_description (GdkPixbufFormat *format)
  *
  * Returns the mime types supported by the format.
  * 
- * Return value: a %NULL-terminated array of mime types which must be freed with 
+ * Return value: (transfer full): a %NULL-terminated array of mime types which must be freed with 
  * g_strfreev() when it is no longer needed.
  *
  * Since: 2.2
@@ -2523,7 +2522,7 @@ gdk_pixbuf_format_get_mime_types (GdkPixbufFormat *format)
  * Returns the filename extensions typically used for files in the 
  * given format.
  * 
- * Return value: a %NULL-terminated array of filename extensions which must be
+ * Return value: (transfer full): a %NULL-terminated array of filename extensions which must be
  * freed with g_strfreev() when it is no longer needed.
  *
  * Since: 2.2
@@ -2650,10 +2649,11 @@ _gdk_pixbuf_get_format (GdkPixbufModule *module)
  * Obtains the available information about the image formats supported
  * by GdkPixbuf.
  *
- * Returns: A list of #GdkPixbufFormat<!-- -->s describing the supported 
- * image formats.  The list should be freed when it is no longer needed, 
- * but the structures themselves are owned by #GdkPixbuf and should not be 
- * freed.  
+ * Returns: (transfer container): (element-type GdkPixbufFormat): A list of
+ * #GdkPixbufFormat<!-- -->s describing the supported
+ * image formats.  The list should be freed when it is no longer needed,
+ * but the structures themselves are owned by #GdkPixbuf and should not be
+ * freed.
  *
  * Since: 2.2
  */
@@ -2721,6 +2721,3 @@ gdk_pixbuf_format_get_type (void)
         }
         return format_id__volatile;
 }
-
-#define __GDK_PIXBUF_IO_C__
-#include "gdk-pixbuf-aliasdef.c"
